# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .creation_policy_principal_type import CreationPolicyPrincipalType
from .creation_policy_resource_type import CreationPolicyResourceType


class NamespaceCreationPolicy(UniversalBaseModel):
    created_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    Creation timestamp.
    """

    created_by: str = pydantic.Field()
    """
    member_id of the actor.
    """

    id: str = pydantic.Field()
    """
    Creation policy row ID.
    """

    namespace_id: str = pydantic.Field()
    """
    Namespace ID.
    """

    principal_id: str = pydantic.Field()
    """
    member_id or group_id.
    """

    principal_type: CreationPolicyPrincipalType = pydantic.Field()
    """
    Principal type receiving the role.
    """

    resource_type: CreationPolicyResourceType = pydantic.Field()
    """
    Resource type this policy applies to.
    """

    role: str = pydantic.Field()
    """
    Direct assignable OpenFGA role.
    """

    updated_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    Last update timestamp.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
