# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SetEnvVarResponse(UniversalBaseModel):
    """
    Response after setting environment variables.
    """

    count: int = pydantic.Field()
    """
    Number of variables set
    """

    redeployed: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether a redeploy was triggered
    """

    updated: typing.List[str] = pydantic.Field()
    """
    Keys that were set
    """

    version_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    New version ID if redeployed
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
