# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .creation_policy_principal_type import CreationPolicyPrincipalType


class NamespaceCreationPolicyInput(UniversalBaseModel):
    principal_id: str = pydantic.Field()
    """
    member_id or group_id.
    """

    principal_type: CreationPolicyPrincipalType = pydantic.Field()
    """
    Principal type receiving the role.
    """

    role: str = pydantic.Field()
    """
    Direct assignable OpenFGA role.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
